@@ -39,10 +39,11 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
+#define UPOWER_ENABLE_DEPRECATED
 #include <libupower-glib/upower.h>
 
 #ifdef WITH_KEYRING
-#include <mate-keyring.h>
+#include <gnome-keyring.h>
 #endif /* WITH_KEYRING */
 
 #include "egg-debug.h"
@@ -212,8 +213,8 @@ gpm_control_suspend (GpmControl *control, GError **error)
 	GpmScreensaver *screensaver;
 	guint32 throttle_cookie = 0;
 #ifdef WITH_KEYRING
-	gboolean lock_mate_keyring;
-	MateKeyringResult keyres;
+	gboolean lock_gnome_keyring;
+	GnomeKeyringResult keyres;
 #endif /* WITH_KEYRING */
 
 	GError *dbus_error = NULL;
@@ -221,7 +222,7 @@ gpm_control_suspend (GpmControl *control, GError **error)
 
 	screensaver = gpm_screensaver_new ();
 
-	if (LOGIND_RUNNING()) {
+	if (!LOGIND_RUNNING()) {
 		g_object_get (control->priv->client,
 			      "can-suspend", &allowed,
 			      NULL);
@@ -234,10 +235,10 @@ gpm_control_suspend (GpmControl *control, GError **error)
 
 #ifdef WITH_KEYRING
 	/* we should perhaps lock keyrings when sleeping #375681 */
-	lock_mate_keyring = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_LOCK_KEYRING_SUSPEND);
-	if (lock_mate_keyring) {
-		keyres = mate_keyring_lock_all_sync ();
-		if (keyres != MATE_KEYRING_RESULT_OK)
+	lock_gnome_keyring = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_LOCK_KEYRING_SUSPEND);
+	if (lock_gnome_keyring) {
+		keyres = gnome_keyring_lock_all_sync ();
+		if (keyres != GNOME_KEYRING_RESULT_OK)
 			egg_warning ("could not lock keyring");
 	}
 #endif /* WITH_KEYRING */
@@ -323,8 +324,8 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 	GpmScreensaver *screensaver;
 	guint32 throttle_cookie = 0;
 #ifdef WITH_KEYRING
-	gboolean lock_mate_keyring;
-	MateKeyringResult keyres;
+	gboolean lock_gnome_keyring;
+	GnomeKeyringResult keyres;
 #endif /* WITH_KEYRING */
 
 	GError *dbus_error = NULL;
@@ -345,10 +346,10 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 
 #ifdef WITH_KEYRING
 	/* we should perhaps lock keyrings when sleeping #375681 */
-	lock_mate_keyring = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_LOCK_KEYRING_HIBERNATE);
-	if (lock_mate_keyring) {
-		keyres = mate_keyring_lock_all_sync ();
-		if (keyres != MATE_KEYRING_RESULT_OK) {
+	lock_gnome_keyring = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_LOCK_KEYRING_HIBERNATE);
+	if (lock_gnome_keyring) {
+		keyres = gnome_keyring_lock_all_sync ();
+		if (keyres != GNOME_KEYRING_RESULT_OK) {
 			egg_warning ("could not lock keyring");
 		}
 	}
