@@ -775,8 +775,8 @@ gpm_manager_idle_do_sleep (GpmManager *manager)
 static void
 gpm_manager_idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmManager *manager)
 {
-	/* ConsoleKit says we are not on active console */
-	if (!egg_console_kit_is_active (manager->priv->console)) {
+	/* ConsoleKit/systemd say we are not on active console */
+	if (!LOGIND_RUNNING() && !egg_console_kit_is_active (manager->priv->console)) {
 		egg_debug ("ignoring as not on active console");
 		return;
 	}
@@ -1004,8 +1004,8 @@ gpm_manager_client_changed_cb (UpClient *client, GpmManager *manager)
 	/* save in local cache */
 	manager->priv->on_battery = on_battery;
 
-	/* ConsoleKit says we are not on active console */
-	if (!egg_console_kit_is_active (manager->priv->console)) {
+	/* ConsoleKit/systemd say we are not on active console */
+	if (!LOGIND_RUNNING() && !egg_console_kit_is_active (manager->priv->console)) {
 		egg_debug ("ignoring as not on active console");
 		return;
 	}
